@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Response::SecureToken;
 
 use Moo;
 
-our $VERSION = '0.000020';
+our $VERSION = '0.000021';
 
 use feature qw( state );
 
@@ -56,7 +56,7 @@ sub _build_hosted_form_uri {
 
     unless ( $res->is_success ) {
 
-        $self->_class_for('Error::HTTP')->throw(
+        $self->_class_for('Error::HTTP')->throw_from_http_response(
             message_prefix => "hosted_form URI does not validate ($uri):",
             http_response  => $res,
             request_uri    => $uri,
@@ -91,7 +91,7 @@ WebService::PayPal::PaymentsAdvanced::Response::SecureToken - Response class for
 
 =head1 VERSION
 
-version 0.000020
+version 0.000021
 
 =head1 SYNOPSIS
 
